"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfigFactory = void 0;
var ConfigFactory_1 = require("./ConfigFactory");
Object.defineProperty(exports, "createConfigFactory", { enumerable: true, get: function () { return ConfigFactory_1.createConfigFactory; } });//# sourceMappingURL=/node_modules/@opentelemetry/configuration/build/src/index.js.map