/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
/**
 * Interface for handling error
 */
export class OTLPExporterError extends Error {
    code;
    name = 'OTLPExporterError';
    data;
    constructor(message, code, data) {
        super(message);
        this.data = data;
        this.code = code;
    }
}//# sourceMappingURL=/node_modules/@opentelemetry/otlp-exporter-base/build/esnext/types.js.map