/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
/**
 * No-op implementations of {@link TextMapPropagator}.
 */
export class NoopTextMapPropagator {
    /** Noop inject function does nothing */
    inject(_context, _carrier) { }
    /** Noop extract function does nothing and returns the input context */
    extract(context, _carrier) {
        return context;
    }
    fields() {
        return [];
    }
}//# sourceMappingURL=/node_modules/@opentelemetry/api/build/esm/propagation/NoopTextMapPropagator.js.map