"use strict";
// Original file: proto/channelz.proto
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=/node_modules/@grpc/grpc-js/build/src/generated/grpc/channelz/v1/GetTopChannelsRequest.js.map