"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OTLPLogExporter = void 0;
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
var node_1 = require("./node");
Object.defineProperty(exports, "OTLPLogExporter", { enumerable: true, get: function () { return node_1.OTLPLogExporter; } });//# sourceMappingURL=/node_modules/@opentelemetry/exporter-logs-otlp-proto/build/src/platform/index.js.map