/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { prepareSend } from './node';//# sourceMappingURL=/node_modules/@opentelemetry/exporter-zipkin/build/esnext/platform/index.js.map