/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { JaegerPropagator, UBER_BAGGAGE_HEADER_PREFIX, UBER_TRACE_ID_HEADER, } from './JaegerPropagator';//# sourceMappingURL=/node_modules/@opentelemetry/propagator-jaeger/build/esnext/index.js.map