"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.trace = void 0;
// Split module-level variable definition into separate files to allow
// tree-shaking on each api instance.
const trace_1 = require("./api/trace");
/**
 * Entrypoint for trace API
 *
 * @since 1.0.0
 */
exports.trace = trace_1.TraceAPI.getInstance();//# sourceMappingURL=/node_modules/@opentelemetry/api/build/src/trace-api.js.map