"use strict";
// Original file: null
Object.defineProperty(exports, "__esModule", { value: true });
exports._google_protobuf_FileOptions_OptimizeMode = void 0;
// Original file: null
exports._google_protobuf_FileOptions_OptimizeMode = {
    SPEED: 'SPEED',
    CODE_SIZE: 'CODE_SIZE',
    LITE_RUNTIME: 'LITE_RUNTIME',
};//# sourceMappingURL=/node_modules/@grpc/grpc-js/build/src/generated/google/protobuf/FileOptions.js.map