/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
import { BatchLogRecordProcessorBase } from '../../../export/BatchLogRecordProcessorBase';
export class BatchLogRecordProcessor extends BatchLogRecordProcessorBase {
    onShutdown() { }
}//# sourceMappingURL=/node_modules/@opentelemetry/sdk-logs/build/esnext/platform/node/export/BatchLogRecordProcessor.js.map