/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { httpAgentFactoryFromOptions } from './configuration/otlp-node-http-configuration';
export { createOtlpHttpExportDelegate } from './otlp-http-export-delegate';
export { getSharedConfigurationFromEnvironment } from './configuration/shared-env-configuration';
export { convertLegacyHttpOptions } from './configuration/convert-legacy-node-http-options';//# sourceMappingURL=/node_modules/@opentelemetry/otlp-exporter-base/build/esnext/index-node-http.js.map