/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
import { noopDetector } from '../../NoopDetector';
export const hostDetector = noopDetector;//# sourceMappingURL=/node_modules/@opentelemetry/resources/build/esnext/detectors/platform/browser/HostDetector.js.map