@theme inline {
	/* Kiro Purple Theme Colors - Using VS Code theme colors */
	--color-kiro-purple-primary: var(--vscode-button-background);
	--color-kiro-purple-secondary: var(--vscode-button-hoverBackground);
	--color-kiro-purple-light: var(--vscode-button-hoverBackground);
	--color-kiro-purple-background: color-mix(
		in srgb,
		var(--color-kiro-purple-primary) 12%,
		transparent
	);

	/* Subscription Colors */
	--color-kiro-free-subscription: var(--vscode-descriptionForeground);

	/* Generic Text Colors */
	--color-kiro-text-primary: var(--vscode-foreground);
	--color-kiro-text-secondary: var(--vscode-descriptionForeground);
	--color-kiro-text-muted: var(--vscode-disabledForeground);

	/* Typography Scale */
	--font-size-kiro-xs: calc(var(--font-size-kiro-md) - 2px);
	--font-size-kiro-sm: calc(var(--font-size-kiro-md) - 1px);
	--font-size-kiro-md: 14px;
	--font-size-kiro-lg: calc(var(--font-size-kiro-md) + 1px);
	--font-size-kiro-xl: calc(var(--font-size-kiro-md) + 3px);
	--font-size-kiro-xxl: calc(var(--font-size-kiro-md) + 5px);
	--font-size-kiro-xxxl: calc(var(--font-size-kiro-md) + 10px);

	/* Font Weight Scale */
	--font-weight-kiro-normal: 300;
	--font-weight-kiro-medium: 400;
	--font-weight-kiro-semibold: 500;
	--font-weight-kiro-bold: 600;

	/* Spacing Scale */
	--spacing-kiro-xxs: calc(var(--spacing-kiro-md) - 14px); /* 2px */
	--spacing-kiro-xs: calc(var(--spacing-kiro-md) - 12px); /* 4px */
	--spacing-kiro-sm: calc(var(--spacing-kiro-md) - 8px); /* 8px */
	--spacing-kiro-md: 16px; /* 16px */
	--spacing-kiro-lg: calc(var(--spacing-kiro-md) + 8px); /* 24px */
	--spacing-kiro-xl: calc(var(--spacing-kiro-md) + 16px); /* 32px */

	/* Border Radius Scale */
	--border-radius-kiro-xs: calc(var(--border-radius-kiro-md) - 4px);
	--border-radius-kiro-sm: calc(var(--border-radius-kiro-md) - 2px);
	--border-radius-kiro-md: 8px;
	--border-radius-kiro-lg: calc(var(--border-radius-kiro-md) + 4px);
	--border-radius-kiro-xl: calc(var(--border-radius-kiro-md) + 8px);

	/* Toggle Switch */
	--vscode-toggleSwitch-onForeground: var(--vscode-inputOption-activeForeground);
	--vscode-toggleSwitch-onBackground: var(--vscode-inputOption-activeBackground);
	--vscode-toggleSwitch-offForeground: var(--vscode-input-foreground);
	--vscode-toggleSwitch-offBackground: var(--vscode-input-background);
	/* Inversed treatment for disabled state */
	--vscode-toggleSwitch-disabledForeground: hsl(from var(--vscode-input-background) h s l / 0.7);
	--vscode-toggleSwitch-disabledBackground: hsl(from var(--vscode-input-foreground) h s l / 0.6);
}
