"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OTLPMetricExporter = void 0;
var OTLPMetricExporter_1 = require("./OTLPMetricExporter");
Object.defineProperty(exports, "OTLPMetricExporter", { enumerable: true, get: function () { return OTLPMetricExporter_1.OTLPMetricExporter; } });//# sourceMappingURL=/node_modules/@opentelemetry/exporter-metrics-otlp-proto/build/src/platform/browser/index.js.map