import { KiroIcon } from "../kiro-logo";

/**
 * Render a header with Kiro logo and welcome message
 */
export function KiroWelcomeTitle(): React.JSX.Element {
	return (
		<h1 className="flex justify-start items-center gap-4 text-white text-[26px] font-normal mb-8">
			<KiroIcon width={56} />
			<span>Welcome to Kiro</span>
		</h1>
	);
}
