"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const ssoOidcClient = require("../../sso-oidc-client-Eo6RRv9S.cjs");
exports.AuthServiceClient = ssoOidcClient.AuthServiceClient;
exports.SSOOIDCClient = ssoOidcClient.SSOOIDCClient;
