"use strict";
// Original file: null
Object.defineProperty(exports, "__esModule", { value: true });
exports.Edition = void 0;
exports.Edition = {
    EDITION_UNKNOWN: 'EDITION_UNKNOWN',
    EDITION_LEGACY: 'EDITION_LEGACY',
    EDITION_PROTO2: 'EDITION_PROTO2',
    EDITION_PROTO3: 'EDITION_PROTO3',
    EDITION_2023: 'EDITION_2023',
    EDITION_2024: 'EDITION_2024',
    EDITION_1_TEST_ONLY: 'EDITION_1_TEST_ONLY',
    EDITION_2_TEST_ONLY: 'EDITION_2_TEST_ONLY',
    EDITION_99997_TEST_ONLY: 'EDITION_99997_TEST_ONLY',
    EDITION_99998_TEST_ONLY: 'EDITION_99998_TEST_ONLY',
    EDITION_99999_TEST_ONLY: 'EDITION_99999_TEST_ONLY',
    EDITION_MAX: 'EDITION_MAX',
};//# sourceMappingURL=/node_modules/@grpc/grpc-js/build/src/generated/google/protobuf/Edition.js.map