(class_declaration
  name: (_) @name.definition.class
  interfaces: (_) @interfaces
)  @definition.class


(method_declaration
  type: (_) @return_type
  name: (_) @name.definition.method
  parameters: (_) @parameters
) @definition.method

(interface_declaration
  name: (_) @name.definition.interface
) @definition.interface
