/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { BatchLogRecordProcessor } from './export/BatchLogRecordProcessor';//# sourceMappingURL=/node_modules/@opentelemetry/sdk-logs/build/esnext/platform/browser/index.js.map