/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
import { TraceStateImpl } from './tracestate-impl';
/**
 * @since 1.1.0
 */
export function createTraceState(rawTraceState) {
    return new TraceStateImpl(rawTraceState);
}//# sourceMappingURL=/node_modules/@opentelemetry/api/build/esnext/trace/internal/utils.js.map