import { describe, it, expect } from "vitest";
import { render, screen } from "@testing-library/react";
import LoadingLogo from "./loading-logo";

describe("LoadingContainerView", () => {
	it("should show loading state", () => {
		render(<LoadingLogo themeType="dark" />);
		expect(screen.getByRole("img", { name: "Logo" })).toBeInTheDocument();
	});
});
