"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_AGGREGATION_TEMPORALITY_SELECTOR = exports.DEFAULT_AGGREGATION_SELECTOR = void 0;
const AggregationTemporality_1 = require("./AggregationTemporality");
const AggregationOption_1 = require("../view/AggregationOption");
const DEFAULT_AGGREGATION_SELECTOR = _instrumentType => {
    return {
        type: AggregationOption_1.AggregationType.DEFAULT,
    };
};
exports.DEFAULT_AGGREGATION_SELECTOR = DEFAULT_AGGREGATION_SELECTOR;
const DEFAULT_AGGREGATION_TEMPORALITY_SELECTOR = _instrumentType => AggregationTemporality_1.AggregationTemporality.CUMULATIVE;
exports.DEFAULT_AGGREGATION_TEMPORALITY_SELECTOR = DEFAULT_AGGREGATION_TEMPORALITY_SELECTOR;//# sourceMappingURL=/node_modules/@opentelemetry/sdk-metrics/build/src/export/AggregationSelector.js.map