"use strict";
// Original file: proto/xds/xds/service/orca/v3/orca.proto
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=/node_modules/@grpc/grpc-js/build/src/generated/xds/service/orca/v3/OrcaLoadReportRequest.js.map