(value_definition
  (let_binding 
    pattern: (_) @name)
) @definition

(module_type_definition
    name: (_) @name) @definition

(class_definition
  (class_binding
    name: (_) @name)
) @definition