/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { OTLPTraceExporter } from './platform';//# sourceMappingURL=/node_modules/@opentelemetry/exporter-trace-otlp-http/build/esnext/index.js.map