"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=/node_modules/@opentelemetry/sdk-trace-base/build/src/IdGenerator.js.map