"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonMetricsSerializer = void 0;
// IMPORTANT: exports added here are public
var metrics_1 = require("./metrics");
Object.defineProperty(exports, "JsonMetricsSerializer", { enumerable: true, get: function () { return metrics_1.JsonMetricsSerializer; } });//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/src/metrics/json/index.js.map