"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonTraceSerializer = exports.JsonMetricsSerializer = exports.JsonLogsSerializer = exports.ProtobufTraceSerializer = exports.ProtobufMetricsSerializer = exports.ProtobufLogsSerializer = void 0;
var protobuf_1 = require("./logs/protobuf");
Object.defineProperty(exports, "ProtobufLogsSerializer", { enumerable: true, get: function () { return protobuf_1.ProtobufLogsSerializer; } });
var protobuf_2 = require("./metrics/protobuf");
Object.defineProperty(exports, "ProtobufMetricsSerializer", { enumerable: true, get: function () { return protobuf_2.ProtobufMetricsSerializer; } });
var protobuf_3 = require("./trace/protobuf");
Object.defineProperty(exports, "ProtobufTraceSerializer", { enumerable: true, get: function () { return protobuf_3.ProtobufTraceSerializer; } });
var json_1 = require("./logs/json");
Object.defineProperty(exports, "JsonLogsSerializer", { enumerable: true, get: function () { return json_1.JsonLogsSerializer; } });
var json_2 = require("./metrics/json");
Object.defineProperty(exports, "JsonMetricsSerializer", { enumerable: true, get: function () { return json_2.JsonMetricsSerializer; } });
var json_3 = require("./trace/json");
Object.defineProperty(exports, "JsonTraceSerializer", { enumerable: true, get: function () { return json_3.JsonTraceSerializer; } });//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/src/index.js.map