import kiroIconSrc from "./kiro-icon.svg";

interface KiroIconProps {
	width: number;
}

/**
 * Kiro "K" logo
 */
export function KiroIcon({ width }: KiroIconProps): React.JSX.Element {
	return <img src={kiroIconSrc} width={width} />;
}
