/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { ProtobufLogsSerializer } from './logs';//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/esnext/logs/protobuf/index.js.map