/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export {};//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/esm/common/protobuf/protobuf-export-type.js.map