"use strict";
/**
 * Copyright (c) 2020 The xterm.js authors. All rights reserved.
 * @license MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=/node_modules/@xterm/addon-image/out/Types.js.map