"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonTraceSerializer = void 0;
// IMPORTANT: exports added here are public
var trace_1 = require("./trace");
Object.defineProperty(exports, "JsonTraceSerializer", { enumerable: true, get: function () { return trace_1.JsonTraceSerializer; } });//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/src/trace/json/index.js.map