import { IPublicSuffix, ISuffixLookupOptions } from 'tldts-core';
/**
 * Check if `hostname` has a valid public suffix in `trie`.
 */
export default function suffixLookup(hostname: string, options: ISuffixLookupOptions, out: IPublicSuffix): void;
