/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
// IMPORTANT: exports added here are public
export { JsonTraceSerializer } from './trace';//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/esm/trace/json/index.js.map