"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SugaredTracer = exports.wrapTracer = void 0;
/**
 * Any exports here may change at any time and without warning
 * @module @opentelemetry/api/experimental
 */
var SugaredTracer_1 = require("./trace/SugaredTracer");
Object.defineProperty(exports, "wrapTracer", { enumerable: true, get: function () { return SugaredTracer_1.wrapTracer; } });
Object.defineProperty(exports, "SugaredTracer", { enumerable: true, get: function () { return SugaredTracer_1.SugaredTracer; } });//# sourceMappingURL=/node_modules/@opentelemetry/api/build/src/experimental/index.js.map