/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { OTLPTraceExporter } from './OTLPTraceExporter';//# sourceMappingURL=/node_modules/@opentelemetry/exporter-trace-otlp-proto/build/esm/platform/node/index.js.map