export function prepareGetHeaders(getExportRequestHeaders) {
    return function () {
        return getExportRequestHeaders();
    };
}//# sourceMappingURL=/node_modules/@opentelemetry/exporter-zipkin/build/esnext/utils.js.map