/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { normalize } from 'path';//# sourceMappingURL=/node_modules/@opentelemetry/instrumentation/build/esm/platform/node/normalize.js.map