/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export {};//# sourceMappingURL=/node_modules/@opentelemetry/api/build/esnext/experimental/trace/SugaredOptions.js.map