/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
/**
 * Any exports here may change at any time and without warning
 * @module @opentelemetry/api/experimental
 */
export { wrapTracer, SugaredTracer } from './trace/SugaredTracer';//# sourceMappingURL=/node_modules/@opentelemetry/api/build/esm/experimental/index.js.map