"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProtobufLogsSerializer = void 0;
var logs_1 = require("./logs");
Object.defineProperty(exports, "ProtobufLogsSerializer", { enumerable: true, get: function () { return logs_1.ProtobufLogsSerializer; } });//# sourceMappingURL=/node_modules/@opentelemetry/otlp-transformer/build/src/logs/protobuf/index.js.map