/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export {};//# sourceMappingURL=/node_modules/@opentelemetry/otlp-exporter-base/build/esnext/transport/node-http-transport-types.js.map