/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { OTLPMetricExporter } from './OTLPMetricExporter';//# sourceMappingURL=/node_modules/@opentelemetry/exporter-metrics-otlp-http/build/esnext/platform/node/index.js.map