import { ModalSectionSeparator } from "./modal-section-separator";

interface ModalSectionContainerProps {
	children: React.ReactNode;
	showSeparatorAfter?: boolean;
	showSeparatorBefore?: boolean;
}

export function ModalSectionContainer({
	children,
	showSeparatorAfter,
	showSeparatorBefore,
}: ModalSectionContainerProps): React.JSX.Element {
	return (
		<>
			{showSeparatorBefore && <ModalSectionSeparator />}
			<div className="kiro-modal-section-container">
				<div className="kiro-modal-section-content">{children}</div>
			</div>
			{showSeparatorAfter && <ModalSectionSeparator />}
		</>
	);
}
