"use strict";
// Original file: null
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=/node_modules/@grpc/grpc-js/build/src/generated/google/protobuf/DescriptorProto.js.map