import { Profile } from "../../types/shared-types";

interface ProfileLinkProps {
	currentProfile: Profile | null;
	canSwitch?: boolean;
	onClick: () => void;
}

export function ProfileLink({
	currentProfile,
	onClick,
}: ProfileLinkProps): React.JSX.Element {
	return (
		<div className="kiro-account-dashboard-profile-link kiro-modal-link">
			Profile:
			<a onClick={onClick}>
				<span>{currentProfile?.name}</span>
				<i className="codicon codicon-chevron-right" />
			</a>
		</div>
	);
}
