import { ReactNode } from "react";

interface ModalLoadingSkeletonProps {
	children?: ReactNode;
}

export function ModalLoadingSkeleton({
	children,
}: ModalLoadingSkeletonProps): React.JSX.Element {
	return <div className="kiro-modal-loading-skeleton">{children}</div>;
}
