"use strict";
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.INVALID_SPAN_CONTEXT = exports.INVALID_TRACEID = exports.INVALID_SPANID = void 0;
const trace_flags_1 = require("./trace_flags");
/**
 * @since 1.0.0
 */
exports.INVALID_SPANID = '0000000000000000';
/**
 * @since 1.0.0
 */
exports.INVALID_TRACEID = '00000000000000000000000000000000';
/**
 * @since 1.0.0
 */
exports.INVALID_SPAN_CONTEXT = {
    traceId: exports.INVALID_TRACEID,
    spanId: exports.INVALID_SPANID,
    traceFlags: trace_flags_1.TraceFlags.NONE,
};//# sourceMappingURL=/node_modules/@opentelemetry/api/build/src/trace/invalid-span-constants.js.map