/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
export { InstrumentationBase } from './instrumentation';
export { normalize } from './normalize';//# sourceMappingURL=/node_modules/@opentelemetry/instrumentation/build/esnext/platform/node/index.js.map