import spinnerIconPath from "./spinner.svg";

/**
 * Spinner
 */
export function Spinner(): React.JSX.Element {
	return (
		<img
			src={spinnerIconPath}
			className="inline-block mr-2 animate-spin"
			alt="Loading..."
		/>
	);
}
